@@ -539,6 +539,11 @@ def module_QtQml() -> ModuleData:
     data.qml.extend(_qml)
 
     data.extra_files.append("qmllint*")
+    # adds qmllint plugins
+    json_data_qmllint = get_module_json_data("QmlCompiler")
+    qml_lint_plugins = get_module_plugins(json_data_qmllint)
+    data.plugins += qml_lint_plugins
+
     data.extra_files.append("qmlformat*")
     data.extra_files.append("qmlls*")
 
@@ -727,6 +732,8 @@ def module_Qt3DInput() -> ModuleData:
 
 def module_Qt3DLogic() -> ModuleData:
     data = ModuleData("3DLogic", qml=["Qt3D/Logic"])
+    json_data = get_module_json_data("3DLogic")
+    data.plugins = get_module_plugins(json_data)
 
     return data
 
@@ -761,10 +768,11 @@ def module_QtQuick3D() -> ModuleData:
         "libQt63DQuick",
         "libQt63DQuickAnimation",
         "libQt63DQuickExtras",
-        "libQt63DQuickExtras",
+        "libQt63DQuickLogic",
         "libQt63DQuickInput",
         "libQt63DQuickRender",
         "libQt63DQuickScene2D",
+        "libQt63DQuickScene3D",
         "libQt6Quick3DXr",
     ]
 
@@ -1032,6 +1040,7 @@ def module_QtVirtualKeyboard() -> ModuleData:
     data = ModuleData("VirtualKeyboard")
     data.plugins.append("virtualkeyboard")
     data.qtlib.append("libQt6VirtualKeyboardSettings")
+    data.qtlib.append("libQt6VirtualKeyboardQml")
 
     return data
 
