@@ -598,8 +598,8 @@ class QAsyncioEventLoop(asyncio.BaseEventLoop, QObject):
     def default_exception_handler(self, context: dict[str, Any]) -> None:
         # TODO
         if context["message"]:
-            print(f"{context["message"]} from task {context["task"]._name},"+
-                    "read the following traceback:")
+            print(f"{context['message']} from task {context['task']._name},"
+                  "read the following traceback:")
             print(context["traceback"])
 
     def call_exception_handler(self, context: dict[str, Any]) -> None:
