@@ -2,7 +2,6 @@
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "dynamicqmetaobject.h"
-#include "pysidelogging_p.h"
 #include "pysideqobject.h"
 #include "pysidesignal.h"
 #include "pysidesignal_p.h"
@@ -10,16 +9,18 @@
 #include "pysideproperty_p.h"
 #include "pysideslot_p.h"
 #include "pysideqenum.h"
-#include "pyside_p.h"
 #include "pysidestaticstrings.h"
 
-#include <shiboken.h>
+#include <autodecref.h>
+#include <gilstate.h>
+#include <sbkstaticstrings.h>
+#include <sbkstring.h>
 
-#include <QtCore/QByteArray>
-#include <QtCore/QObject>
-#include <QtCore/QStringList>
-#include <QtCore/QTextStream>
-#include <QtCore/QList>
+#include <QtCore/qbytearray.h>
+#include <QtCore/qobject.h>
+#include <QtCore/qstringlist.h>
+#include <QtCore/qtextstream.h>
+#include <QtCore/qlist.h>
 #include <private/qmetaobjectbuilder_p.h>
 
 #include <cstring>
@@ -591,7 +592,7 @@ void MetaObjectBuilderPrivate::parsePythonType(PyTypeObject *type)
     basesToCheck.push_back(type);
 
     auto *sbkObjTypeF = SbkObject_TypeF();
-    auto *baseObjType = reinterpret_cast<PyTypeObject *>(&PyBaseObject_Type);
+    auto *baseObjType = &PyBaseObject_Type;
     for (Py_ssize_t i = 0; i < basesCount; ++i) {
         auto *baseType = reinterpret_cast<PyTypeObject *>(PyTuple_GetItem(mro, i));
         if (baseType != sbkObjTypeF && baseType != baseObjType
