@@ -6,13 +6,20 @@
 #include "pysideproperty_p.h"
 #include "pysidesignal.h"
 #include "pysidesignal_p.h"
+#include "signalmanager.h"
 
-#include <shiboken.h>
+#include <autodecref.h>
 #include <pep384ext.h>
+#include <sbkconverter.h>
+#include <sbkstaticstrings.h>
+#include <sbkstring.h>
+#include <sbktypefactory.h>
 #include <signature.h>
 
 using namespace Shiboken;
 
+using namespace Qt::StringLiterals;
+
 extern "C"
 {
 
@@ -144,16 +151,20 @@ void PySidePropertyPrivate::metaCall(PyObject *source, QMetaObject::Call call, v
     switch (call) {
     case QMetaObject::ReadProperty: {
         AutoDecRef value(getValue(source));
-        auto *obValue = value.object();
-        if (obValue) {
-            Conversions::SpecificConverter converter(typeName);
-            if (converter) {
-                converter.toCpp(obValue, args[0]);
-            } else {
-                // PYSIDE-2160: Report an unknown type name to the caller `qtPropertyMetacall`.
-                PyErr_SetObject(PyExc_StopIteration, obValue);
-            }
+        if (value.isNull())
+            return;
+        if (typeName == "PyObject"_ba) {
+            // Manual conversion, see PyObjectWrapper converter registration
+            auto *pw = reinterpret_cast<PySide::PyObjectWrapper *>(args[0]);
+            pw->reset(value.object());
+            return;
         }
+        if (Conversions::SpecificConverter converter(typeName); converter) {
+            converter.toCpp(value.object(), args[0]);
+            return;
+        }
+        // PYSIDE-2160: Report an unknown type name to the caller `qtPropertyMetacall`.
+        PyErr_SetObject(PyExc_StopIteration, value.object());
     }
         break;
 
@@ -471,11 +482,11 @@ namespace PySide::Property {
 
 static const char *Property_SignatureStrings[] = {
     "PySide6.QtCore.Property(self,type:type,"
-        "fget:typing.Optional[collections.abc.Callable[[typing.Any],typing.Any]],"
-        "fset:typing.Optional[collections.abc.Callable[[typing.Any,typing.Any],None]],"
-        "freset:typing.Optional[collections.abc.Callable[[typing.Any,typing.Any],None]],"
+        "fget:typing.Optional[collections.abc.Callable[[typing.Any],typing.Any]]=None,"
+        "fset:typing.Optional[collections.abc.Callable[[typing.Any,typing.Any],None]]=None,"
+        "freset:typing.Optional[collections.abc.Callable[[typing.Any,typing.Any],None]]=None,"
         "doc:str=None,"
-        "notify:typing.Optional[collections.abc.Callable[[],None]],"
+        "notify:typing.Optional[collections.abc.Callable[[],None]]=None,"
         "designable:bool=True,scriptable:bool=True,"
         "stored:bool=True,user:bool=False,constant:bool=False,final:bool=False)",
     "PySide6.QtCore.Property.deleter(self,fdel:collections.abc.Callable[[typing.Any],None])->PySide6.QtCore.Property",
