@@ -7,30 +7,31 @@
 #include "pysidemacros.h"
 #include <sbkpython.h>
 
-#include <QtCore/QObject>
+#include <QtCore/qobject.h>
 #include <QtCore/qobjectdefs.h>
 
+#include <memory>
+
 namespace PySide
 {
 
+class DynamicSlot;
+
 class PySideQSlotObject : public QtPrivate::QSlotObjectBase
 {
-    PyObject *callable;
-
-    static void impl(int which, QSlotObjectBase *this_, QObject *receiver, void **args, bool *ret);
-
+    Q_DISABLE_COPY_MOVE(PySideQSlotObject)
 public:
-    PySideQSlotObject(PyObject *callable) : QtPrivate::QSlotObjectBase(&impl), callable(callable)
-    {
-        Py_INCREF(callable);
-    }
+    explicit PySideQSlotObject(PyObject *callable, const QByteArrayList &parameterTypes,
+                               const char *returnType  = nullptr);
+    ~PySideQSlotObject();
 
-    ~PySideQSlotObject()
-    {
-        auto gstate = PyGILState_Ensure();
-        Py_DECREF(callable);
-        PyGILState_Release(gstate);
-    }
+private:
+    static void impl(int which, QSlotObjectBase *this_, QObject *receiver, void **args, bool *ret);
+    void call(void **args);
+
+    std::unique_ptr<DynamicSlot> m_dynamicSlot;
+    const QByteArrayList m_parameterTypes;
+    const char *m_returnType;
 };
 
 
