@@ -19,14 +19,17 @@
 #include <sbkstaticstrings.h>
 #include <sbkerrors.h>
 
-#include <QtCore/QCoreApplication>
-#include <QtCore/QByteArrayView>
-#include <QtCore/QDebug>
-#include <QtCore/QHash>
-#include <QtCore/QScopedPointer>
-#include <QtCore/QTimerEvent>
+#include <QtCore/qbytearrayview.h>
+#include <QtCore/qcoreapplication.h>
+#include <QtCore/qcoreevent.h>
+#include <QtCore/qdebug.h>
+#include <QtCore/qhash.h>
+#include <QtCore/qmetatype.h>
+#include <QtCore/qscopedpointer.h>
 
+#include <climits>
 #include <memory>
+#include <utility>
 
 using namespace Qt::StringLiterals;
 
@@ -36,6 +39,8 @@ using namespace Qt::StringLiterals;
 
 static PyObject *metaObjectAttr = nullptr;
 
+static int pyObjectWrapperMetaTypeId = QMetaType::UnknownType;
+
 static void destroyMetaObject(PyObject *obj)
 {
     void *ptr = PyCapsule_GetPointer(obj, nullptr);
@@ -125,6 +130,17 @@ PyObjectWrapper::PyObjectWrapper(const PyObjectWrapper &other)
     Py_XINCREF(m_me);
 }
 
+PyObjectWrapper::PyObjectWrapper(PyObjectWrapper &&other) noexcept
+ : m_me{std::exchange(other.m_me, nullptr)}
+{
+}
+
+PyObjectWrapper &PyObjectWrapper::operator=(PyObjectWrapper &&other) noexcept
+{
+    m_me = std::exchange(other.m_me, nullptr);
+    return *this;
+}
+
 PyObjectWrapper::~PyObjectWrapper()
 {
     // Check that Python is still initialized as sometimes this is called by a static destructor
@@ -156,6 +172,10 @@ PyObjectWrapper::operator PyObject *() const
     return m_me;
 }
 
+int PyObjectWrapper::metaTypeId()
+{
+    return pyObjectWrapperMetaTypeId;
+}
 
 int PyObjectWrapper::toInt() const
 {
@@ -221,7 +241,29 @@ QDataStream &operator>>(QDataStream &in, PyObjectWrapper &myObj)
     return in;
 }
 
-};
+PYSIDE_API QDebug operator<<(QDebug debug, const PyObjectWrapper &myObj)
+{
+    QDebugStateSaver saver(debug);
+    debug.noquote();
+    debug.nospace();
+    // Do not repeat the type name as it is typically called from the QVariant debug
+    // operator, which outputs the type.
+    debug << '<';
+    if (PyObject *ob = myObj) {
+        const auto refs = Py_REFCNT(ob);
+        debug << Py_TYPE(ob)->tp_name << " at " << ob;
+        if (refs == UINT_MAX) // _Py_IMMORTAL_REFCNT
+            debug << ", immortal";
+        else
+            debug << ", refs=" << refs;
+    } else {
+        debug << '0';
+    }
+    debug << '>';
+    return debug;
+}
+
+} // namespace PySide
 
 using namespace PySide;
 
@@ -238,19 +280,11 @@ struct SignalManagerPrivate
 SignalManager::QmlMetaCallErrorHandler
     SignalManagerPrivate::m_qmlMetaCallErrorHandler = nullptr;
 
-static void PyObject_PythonToCpp_PyObject_PTR(PyObject *pyIn, void *cppOut)
+static PyObject *CopyCppToPythonPyObject(const void *cppIn)
 {
-    *reinterpret_cast<PyObject **>(cppOut) = pyIn;
-}
-static PythonToCppFunc is_PyObject_PythonToCpp_PyObject_PTR_Convertible(PyObject * /* pyIn */)
-{
-    return PyObject_PythonToCpp_PyObject_PTR;
-}
-static PyObject *PyObject_PTR_CppToPython_PyObject(const void *cppIn)
-{
-    auto *pyOut = reinterpret_cast<PyObject *>(const_cast<void *>(cppIn));
-    if (pyOut)
-        Py_INCREF(pyOut);
+    const auto *wrapper = reinterpret_cast<const PyObjectWrapper *>(cppIn);
+    PyObject *pyOut = *wrapper;
+    Py_XINCREF(pyOut);
     return pyOut;
 }
 
@@ -260,13 +294,16 @@ void SignalManager::init()
     using namespace Shiboken;
 
     // Register PyObject type to use in queued signal and slot connections
-    qRegisterMetaType<PyObjectWrapper>("PyObject");
+    pyObjectWrapperMetaTypeId = qRegisterMetaType<PyObjectWrapper>("PyObject");
     // Register QVariant(enum) conversion to QVariant(int)
     QMetaType::registerConverter<PyObjectWrapper, int>(&PyObjectWrapper::toInt);
 
-    SbkConverter *converter = Shiboken::Conversions::createConverter(&PyBaseObject_Type, nullptr);
-    Shiboken::Conversions::setCppPointerToPythonFunction(converter, PyObject_PTR_CppToPython_PyObject);
-    Shiboken::Conversions::setPythonToCppPointerFunctions(converter, PyObject_PythonToCpp_PyObject_PTR, is_PyObject_PythonToCpp_PyObject_PTR_Convertible);
+    // Register a shiboken converter for PyObjectWrapper->Python (value conversion).
+    // Python->PyObjectWrapper is not registered since the converters do not work for
+    // non-SbkObject types (falling back to plain pointer pass through).
+    // This conversion needs to be done manually via QVariant.
+    SbkConverter *converter = Shiboken::Conversions::createConverter(&PyBaseObject_Type,
+                                                                     CopyCppToPythonPyObject);
     Shiboken::Conversions::registerConverterName(converter, "PyObject");
     Shiboken::Conversions::registerConverterName(converter, "object");
     Shiboken::Conversions::registerConverterName(converter, "PyObjectWrapper");
@@ -407,7 +444,7 @@ int SignalManagerPrivate::qtMethodMetacall(QObject *object,
     //         because the object can be deleted inside the called slot.
 
     if (gil == nullptr)
-        gil.reset(new Shiboken::GilState);
+        gil = std::make_unique<Shiboken::GilState>();
 
     if (PyErr_Occurred())
         handleMetaCallError(object, &result);
@@ -464,16 +501,21 @@ static int callPythonMetaMethodHelper(const QByteArrayList &paramTypes,
                                       const char *returnType /* = nullptr */,
                                       void **args, PyObject *pyCallable)
 {
+    using SpecificConverter = Shiboken::Conversions::SpecificConverter;
     const qsizetype argsSize = paramTypes.size();
     Shiboken::AutoDecRef preparedArgs(PyTuple_New(argsSize));
 
     for (qsizetype i = 0; i < argsSize; ++i) {
         void *data = args[i + 1];
-        auto param = paramTypes.at(i);
-        Shiboken::Conversions::SpecificConverter converter(param.constData());
+        const auto &param = paramTypes.at(i);
+        SpecificConverter converter(param.constData());
         if (!converter.isValid())
             return CallResult::CallArgumentError + int(i);
-        PyTuple_SetItem(preparedArgs, i, converter.toPython(data));
+        // Only pointer conversion available for const-ref - add indirection
+        const bool valueToPtr = converter.conversionType() == SpecificConverter::PointerConversion
+            && !param.endsWith('*') && param != "PyObject"_ba;
+        auto *src = valueToPtr ? &data : data;
+        PyTuple_SetItem(preparedArgs, i, converter.toPython(src));
     }
 
     QScopedPointer<Shiboken::Conversions::SpecificConverter> retConverter;
