@@ -12,21 +12,22 @@
 #include <optional>
 
 // shiboken
-#include <shiboken.h>
+#include <autodecref.h>
+#include <sbkconverter.h>
 #include <sbkstring.h>
+#include <sbktypefactory.h>
 
 // pyside
-#include <pyside.h>
 #include <pysideqobject.h>
 #include <pysideclassinfo.h>
 #include <pyside_p.h>
 
-#include <QtCore/QMutex>
-#include <QtCore/QTypeRevision>
+#include <QtCore/qmutex.h>
+#include <QtCore/qtyperevision.h>
 
 #include <QtQml/qqml.h>
-#include <QtQml/QJSValue>
-#include <QtQml/QQmlListProperty>
+#include <QtQml/qjsvalue.h>
+#include <QtQml/qqmllist.h>
 #include <private/qqmlmetatype_p.h>
 #include <private/qmetaobjectbuilder_p.h>
 
