@@ -4,9 +4,9 @@
 #ifndef PY_CUSTOM_WIDGET_H_
 #define PY_CUSTOM_WIDGET_H_
 
-#include <shiboken.h>
+#include <sbkpython.h>
 
-#include <QtUiPlugin/QDesignerCustomWidgetInterface>
+#include <QtUiPlugin/customwidget.h>
 
 class PyCustomWidget: public QObject, public QDesignerCustomWidgetInterface
 {
