@@ -4,9 +4,9 @@
 #ifndef PY_CUSTOM_WIDGETS_H_
 #define PY_CUSTOM_WIDGETS_H_
 
-#include <shiboken.h>
+#include <sbkpython.h>
 
-#include <QtUiPlugin/QDesignerCustomWidgetInterface>
+#include <QtUiPlugin/customwidget.h>
 
 #include <QtCore/qlist.h>
 
