@@ -4,10 +4,18 @@ from __future__ import annotations
 
 '''Test cases for the QIOPipe class'''
 
-from PySide6.QtCore import QIODevice, QIOPipe
-
+import os
+import sys
 import unittest
 
+from pathlib import Path
+sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
+from init_paths import init_test_paths
+init_test_paths(False)
+
+
+from PySide6.QtCore import QIODevice, QIOPipe
+
 
 class QIOPipeTest(unittest.TestCase):
     def setUp(self) -> None:
