@@ -10,10 +10,10 @@ import unittest
 
 from pathlib import Path
 sys.path.append(os.fspath(Path(__file__).resolve().parents[1]))
-from init_paths import init_test_paths
+from init_paths import init_test_paths  # noqa: E402
 init_test_paths(False)
 
-from PySide6.QtLocation import QGeoServiceProvider
+from PySide6.QtLocation import QGeoServiceProvider  # noqa: E402
 
 
 class QLocationTestCase(unittest.TestCase):
