@@ -25,8 +25,8 @@
 
 #include "qtcompat.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QRegularExpression>
+#include <QtCore/qdebug.h>
+#include <QtCore/qregularexpression.h>
 
 #include <algorithm>
 
@@ -59,8 +59,9 @@ public:
     QString modifiedName(const AbstractMetaFunction *q) const;
     int overloadNumber(const AbstractMetaFunction *q) const;
 
-    const FunctionModificationList &modifications(const AbstractMetaFunction *q,
-                                                  const AbstractMetaClassCPtr &implementor) const;
+    const FunctionModificationList &globalModifications(const AbstractMetaFunction *q) const;
+    const FunctionModificationList &memberModifications(const AbstractMetaFunction *q,
+                                                        const AbstractMetaClassCPtr &implementor) const;
 
     bool applyTypeModification(const AbstractMetaFunction *q,
                                const QString &type, int number, QString *errorMessage);
@@ -71,7 +72,7 @@ public:
     mutable QString m_cachedMinimalSignature;
     mutable QString m_cachedSignature;
     mutable QString m_cachedModifiedName;
-    QString m_unresolvedSignature;
+    QStringList m_unresolvedSignatures;
 
     FunctionTypeEntryPtr m_typeEntry;
     AbstractMetaFunction::FunctionType m_functionType = AbstractMetaFunction::NormalFunction;
@@ -80,6 +81,7 @@ public:
     AbstractMetaClassCPtr m_class;
     AbstractMetaClassCPtr m_implementingClass;
     AbstractMetaClassCPtr m_declaringClass;
+    AbstractMetaFunctionCPtr m_overridden; /// overridden base function of a virtual
     mutable ModificationCache m_modificationCache;
     int m_propertySpecIndex = -1;
     AbstractMetaArgumentList m_arguments;
@@ -224,9 +226,8 @@ void AbstractMetaFunction::setExplicit(bool isExplicit)
 
 bool AbstractMetaFunction::returnsBool() const
 {
-    if (d->m_type.typeUsagePattern() != AbstractMetaType::PrimitivePattern)
-        return false;
-    return basicReferencedTypeEntry(d->m_type.typeEntry())->name() == u"bool";
+    return d->m_type.typeUsagePattern() == AbstractMetaType::PrimitivePattern
+        && d->m_type.basicPrimitiveName() == "bool"_L1;
 }
 
 bool AbstractMetaFunction::isOperatorBool() const
@@ -338,12 +339,6 @@ void AbstractMetaFunction::setOwnerClass(const AbstractMetaClassCPtr &cls)
     d->m_class = cls;
 }
 
-bool AbstractMetaFunction::operator<(const AbstractMetaFunction &other) const
-{
-    return compareTo(&other) & NameLessThan;
-}
-
-
 /*!
     Returns a mask of CompareResult describing how this function is
     compares to another function
@@ -352,65 +347,44 @@ AbstractMetaFunction::CompareResult AbstractMetaFunction::compareTo(const Abstra
 {
     CompareResult result;
 
-    // Enclosing class...
-    if (ownerClass() == other->ownerClass())
-        result |= EqualImplementor;
-
-    // Attributes
-    if (attributes() == other->attributes() && cppAttributes() == other->cppAttributes())
-        result |= EqualAttributes;
-
     // Compare types
-    if (type().name() == other->type().name())
-        result |= EqualReturnType;
+    if (type() == other->type())
+        result.setFlag(EqualReturnType);
 
     // Compare names
-    int cmp = originalName().compare(other->originalName());
+    if (originalName() == other->originalName())
+        result.setFlag(EqualName);
 
-    if (cmp < 0)
-        result |= NameLessThan;
-    else if (!cmp)
-        result |= EqualName;
+    if (isStatic() == other->isStatic())
+        result.setFlag(EqualStatic);
+
+    if (isConstant() == other->isConstant())
+        result.setFlag(EqualConst);
+
+    if (isVirtual()  == other->isVirtual())
+        result.setFlag(EqualVirtual);
 
     // compare name after modification...
-    cmp = modifiedName().compare(other->modifiedName());
-    if (!cmp)
-        result |= EqualModifiedName;
+    if (modifiedName() == other->modifiedName())
+        result.setFlag(EqualModifiedName);
 
     // Compare arguments...
-    AbstractMetaArgumentList minArguments;
-    AbstractMetaArgumentList maxArguments;
-    if (arguments().size() < other->arguments().size()) {
-        minArguments = arguments();
-        maxArguments = other->arguments();
-    } else {
-        minArguments = other->arguments();
-        maxArguments = arguments();
-    }
-
-    const auto minCount = minArguments.size();
-    const auto maxCount = maxArguments.size();
-    bool same = true;
-    for (qsizetype i = 0; i < maxCount; ++i) {
-        if (i < minCount) {
-            const AbstractMetaArgument &min_arg = minArguments.at(i);
-            const AbstractMetaArgument &max_arg = maxArguments.at(i);
-            if (min_arg.type().name() != max_arg.type().name()
-                && (min_arg.defaultValueExpression().isEmpty() || max_arg.defaultValueExpression().isEmpty())) {
-                same = false;
-                break;
-            }
-        } else {
-            if (maxArguments.at(i).defaultValueExpression().isEmpty()) {
-                same = false;
-                break;
+    const auto argumentCount = d->m_arguments.size();
+    const auto &otherArguments = other->arguments();
+    if (argumentCount == otherArguments.size()) {
+        result.setFlag(EqualArgumentCount);
+        bool equals = true;
+        for (qsizetype a = 0; a < argumentCount; ++a) {
+            if ((d->m_arguments.at(a).type() != otherArguments.at(a).type())) {
+                equals = false;
+                if (a < 4)
+                    result.setFlag(CompareResultFlag(DifferArgument1 << a));
             }
         }
+        if (equals)
+            result.setFlag(EqualArguments);
     }
 
-    if (same)
-        result |= minCount == maxCount ? EqualArguments : EqualDefaultValueOverload;
-
     return result;
 }
 
@@ -438,6 +412,16 @@ bool AbstractMetaFunction::isConstOverloadOf(const AbstractMetaFunction *other)
     return true;
 }
 
+AbstractMetaFunctionCPtr AbstractMetaFunction::overridden() const
+{
+    return d->m_overridden;
+}
+
+void AbstractMetaFunction::setOverriddden(const AbstractMetaFunctionCPtr &o)
+{
+    d->m_overridden = o;
+}
+
 AbstractMetaFunction *AbstractMetaFunction::copy() const
 {
     auto *cpy = new AbstractMetaFunction;
@@ -489,6 +473,7 @@ bool AbstractMetaFunction::generateBinding() const
     case AssignmentOperatorFunction:
     case MoveAssignmentOperatorFunction:
     case AbstractMetaFunction::MoveConstructorFunction:
+    case OtherAssignmentOperatorFunction:
         return false;
     default:
         if (!isWhiteListed())
@@ -569,14 +554,14 @@ QString AbstractMetaFunction::classQualifiedSignature() const
     return result;
 }
 
-QString AbstractMetaFunction::unresolvedSignature() const
+QStringList AbstractMetaFunction::unresolvedSignatures() const
 {
-    return d->m_unresolvedSignature;
+    return d->m_unresolvedSignatures;
 }
 
-void AbstractMetaFunction::setUnresolvedSignature(const QString &s)
+void AbstractMetaFunction::setUnresolvedSignatures(const QStringList &s)
 {
-    d->m_unresolvedSignature = s;
+    d->m_unresolvedSignatures = s;
 }
 
 bool AbstractMetaFunction::isConstant() const
@@ -1039,8 +1024,10 @@ QString AbstractMetaFunction::minimalSignature() const
 QStringList AbstractMetaFunction::modificationSignatures() const
 {
     QStringList result{minimalSignature()};
-    if (d->m_unresolvedSignature != result.constFirst())
-        result.append(d->m_unresolvedSignature);
+    for (const auto &signature : std::as_const(d->m_unresolvedSignatures)) {
+        if (signature != result.constFirst())
+            result.append(signature);
+    }
     return result;
 }
 
@@ -1067,19 +1054,30 @@ QString AbstractMetaFunction::debugSignature() const
     return result;
 }
 
-FunctionModificationList AbstractMetaFunction::findClassModifications(const AbstractMetaFunction *f,
-                                                                      AbstractMetaClassCPtr implementor)
+static void findModificationRecursion(const QStringList &signatures,
+                                      const AbstractMetaClassCPtr &implementor,
+                                      const AbstractMetaClassCPtr &stopAt,
+                                      unsigned level, FunctionModificationList *result)
+{
+    auto mods = implementor->typeEntry()->functionModifications(signatures);
+    for (auto &mod : mods)
+        mod.setInherited(level != 0);
+    result->append(mods);
+    if (implementor->inheritanceDone() // AbstractMetaBuilder phase?
+        && (implementor != stopAt || mods.isEmpty())) {
+        level += 1;
+        for (const auto &base : implementor->baseClasses())
+            findModificationRecursion(signatures, base, stopAt, level, result);
+    }
+}
+
+FunctionModificationList
+AbstractMetaFunction::findMemberModifications(const AbstractMetaFunction *f,
+                                              const AbstractMetaClassCPtr &implementor)
 {
     const auto signatures = f->modificationSignatures();
     FunctionModificationList mods;
-    while (implementor) {
-        mods += implementor->typeEntry()->functionModifications(signatures);
-        if ((implementor == implementor->baseClass()) ||
-            (implementor == f->implementingClass() && !mods.isEmpty())) {
-                break;
-        }
-        implementor = implementor->baseClass();
-    }
+    findModificationRecursion(signatures, implementor, f->implementingClass(), 0, &mods);
     return mods;
 }
 
@@ -1090,29 +1088,42 @@ FunctionModificationList AbstractMetaFunction::findGlobalModifications(const Abs
 }
 
 const FunctionModificationList &
-    AbstractMetaFunctionPrivate::modifications(const AbstractMetaFunction *q,
-                                               const AbstractMetaClassCPtr &implementor) const
+    AbstractMetaFunctionPrivate::globalModifications(const AbstractMetaFunction *q) const
 {
+    if (m_addedFunction)
+        return m_addedFunction->modifications();
+    if (m_modificationCache.isEmpty())
+        m_modificationCache.append({{}, AbstractMetaFunction::findGlobalModifications(q)});
+    return m_modificationCache.constFirst().modifications;
+}
+
+const FunctionModificationList &
+    AbstractMetaFunctionPrivate::memberModifications(const AbstractMetaFunction *q,
+                                                     const AbstractMetaClassCPtr &implementor) const
+{
+    Q_ASSERT(implementor);
     if (m_addedFunction)
         return m_addedFunction->modifications();
     for (const auto &ce : m_modificationCache) {
         if (ce.klass == implementor)
             return ce.modifications;
     }
-    auto modifications = m_class == nullptr
-        ? AbstractMetaFunction::findGlobalModifications(q)
-        : AbstractMetaFunction::findClassModifications(q, implementor);
 
+    auto modifications = AbstractMetaFunction::findMemberModifications(q, implementor);
     m_modificationCache.append({implementor, modifications});
     return m_modificationCache.constLast().modifications;
 }
 
 const FunctionModificationList &
-    AbstractMetaFunction::modifications(AbstractMetaClassCPtr implementor) const
+    AbstractMetaFunction::modifications(const AbstractMetaClassCPtr &implementor) const
 {
-    if (!implementor)
-        implementor = d->m_class;
-    return d->modifications(this, implementor);
+    // Note: m_class might be null here in early stages of AbstractMetaBuilder.
+    // Fully rely on implementor, then.
+    if (implementor)
+        return d->memberModifications(this, implementor);
+    if (d->m_class)
+        return d->memberModifications(this, d->m_class);
+    return d->globalModifications(this);
 }
 
 void AbstractMetaFunction::clearModificationsCache()
@@ -1670,8 +1681,8 @@ void AbstractMetaFunction::formatDebugVerbose(QDebug &debug) const
     }
     const QString signature = minimalSignature();
     debug << "), signature=\"" << signature << '"';
-    if (signature != d->m_unresolvedSignature)
-        debug << ", unresolvedSignature=\"" << d->m_unresolvedSignature << '"';
+    if (!d->m_unresolvedSignatures.isEmpty())
+        debug << ", unresolvedSignatures=\"" << d->m_unresolvedSignatures << '"';
     if (d->m_constant)
         debug << " [const]";
     if (d->m_reverse)
