@@ -9,17 +9,19 @@
 #include "containertypeentry.h"
 #include "enumtypeentry.h"
 #include "flagstypeentry.h"
+#include "cpptypeentry.h"
+#include "primitivetypeentry.h"
 
 #include "qtcompat.h"
 #include "typeinfo.h"
 
 #ifndef QT_NO_DEBUG_STREAM
-#  include <QtCore/QDebug>
+#  include <QtCore/qdebug.h>
 #endif
 
-#include <QtCore/QHash>
-#include <QtCore/QSharedData>
-#include <QtCore/QStack>
+#include <QtCore/qhash.h>
+#include <QtCore/qshareddata.h>
+#include <QtCore/qstack.h>
 
 #include <memory>
 
@@ -111,6 +113,7 @@ public:
     AbstractMetaTypeData(const TypeEntryCPtr &t);
 
     int actualIndirections() const;
+    bool passByRef() const;
     bool passByConstRef() const;
     bool passByValue() const;
     AbstractMetaType::TypeUsagePattern determineUsagePattern() const;
@@ -194,6 +197,12 @@ QString AbstractMetaType::name() const
     return d->m_typeEntry->targetLangEntryName();
 }
 
+QString AbstractMetaType::basicPrimitiveName() const
+{
+    return d->m_typeEntry->isPrimitive()
+        ? basicReferencedTypeEntry(d->m_typeEntry)->name() : name();
+}
+
 QString AbstractMetaType::fullName() const
 {
     return d->m_typeEntry->qualifiedTargetLangName();
@@ -336,9 +345,19 @@ AbstractMetaTypeList AbstractMetaType::nestedArrayTypes() const
     return result;
 }
 
+bool AbstractMetaTypeData::passByRef() const
+{
+    return m_referenceType == LValueReference && m_indirections.isEmpty();
+}
+
 bool AbstractMetaTypeData::passByConstRef() const
 {
-    return m_constant && m_referenceType == LValueReference && m_indirections.isEmpty();
+    return m_constant && passByRef();
+}
+
+bool AbstractMetaType::passByRef() const
+{
+    return d->passByRef();
 }
 
 bool AbstractMetaType::passByConstRef() const
@@ -358,7 +377,7 @@ bool AbstractMetaType::passByValue() const
 
 bool AbstractMetaType::useStdMove() const
 {
-    return (isUniquePointer() && d->passByValue())
+    return (isMoveOnlyType() && d->passByValue())
         || d->m_referenceType == RValueReference;
 }
 
@@ -745,6 +764,24 @@ void AbstractMetaType::setVolatile(bool v)
     }
 }
 
+bool AbstractMetaType::isDefaultConstructible() const
+{
+    auto cppTe = std::dynamic_pointer_cast<const CppTypeEntry>(d->m_typeEntry);
+    return cppTe != nullptr && cppTe->isDefaultConstructible();
+}
+
+bool AbstractMetaType::isCopyable() const
+{
+    auto cppTe = std::dynamic_pointer_cast<const CppTypeEntry>(d->m_typeEntry);
+    return cppTe != nullptr && cppTe->isCopyable();
+}
+
+bool AbstractMetaType::isMovable() const
+{
+    auto cppTe = std::dynamic_pointer_cast<const CppTypeEntry>(d->m_typeEntry);
+    return cppTe != nullptr && cppTe->isMovable();
+}
+
 static bool equalsCPtr(const AbstractMetaTypeCPtr &t1, const AbstractMetaTypeCPtr &t2)
 {
     if (bool(t1) != bool(t2))
@@ -854,11 +891,6 @@ bool AbstractMetaType::isObjectType() const
     return d->m_typeEntry->isObject();
 }
 
-bool AbstractMetaType::isUniquePointer() const
-{
-    return isSmartPointer() && d->m_typeEntry->isUniquePointer();
-}
-
 bool AbstractMetaType::isPointer() const
 {
     return !d->m_indirections.isEmpty()
@@ -929,16 +961,16 @@ bool AbstractMetaType::isExtendedCppPrimitive() const
 bool AbstractMetaType::isValueTypeWithCopyConstructorOnly() const
 {
     bool result = false;
-    if (d->m_typeEntry->isComplex()) {
-        const auto cte = std::static_pointer_cast<const ComplexTypeEntry>(d->m_typeEntry);
-        result = cte->isValueTypeWithCopyConstructorOnly();
+    if (isValue()) {
+        auto cppTe = std::static_pointer_cast<const CppTypeEntry>(d->m_typeEntry);
+        result = !cppTe->isDefaultConstructible() && cppTe->isCopyable();
     }
     return result;
 }
 
 bool AbstractMetaType::valueTypeWithCopyConstructorOnlyPassed() const
 {
-    return (passByValue() || passByConstRef())
+    return (passByValue() || passByRef())
            && isValueTypeWithCopyConstructorOnly();
 }
 
