@@ -17,11 +17,12 @@
 
 #include "qtcompat.h"
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QStringList>
-#include <QtCore/QXmlStreamReader>
+#include <QtCore/qdebug.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qfile.h>
+#include <QtCore/qlibraryinfo.h>
+#include <QtCore/qstringlist.h>
+#include <QtCore/qxmlstream.h>
 
 #include <algorithm>
 #include <iterator>
@@ -46,6 +47,20 @@ static QTextStream &operator<<(QTextStream &s, Access a)
     return s;
 }
 
+QString msgModificationCandidates(const AbstractMetaFunctionCPtr &function)
+{
+    QString result;
+    const auto &signatures = function->modificationSignatures();
+    for (qsizetype i = 0, size = signatures.size(); i < size; ++i) {
+        if (i > 0)
+            result += " / "_L1;
+        result += u'"' + signatures.at(i) + u'"';
+    }
+    if (auto klazz = function->implementingClass())
+        result += " in "_L1 + klazz->name();
+    return result;
+}
+
 QString msgNoFunctionForModification(const AbstractMetaClassCPtr &klass,
                                      const QString &signature,
                                      const QString &originalSignature,
@@ -75,6 +90,19 @@ QString msgNoFunctionForModification(const AbstractMetaClassCPtr &klass,
     return result;
 }
 
+QString msgModificationConstMismatch(const AbstractMetaFunctionCPtr &function,
+                                     const QString &modificationSignature)
+{
+    QString result;
+    QTextStream str(&result);
+    if (auto klazz = function->implementingClass())
+        str << klazz->typeEntry()->sourceLocation();
+    str << "signature \"" << modificationSignature
+        << "\" needs \"const\" to fully match \"" << function->classQualifiedSignature()
+        << "\". The partial matching will be removed in a future release.";
+    return result;
+}
+
 QString msgArgumentIndexOutOfRange(const AbstractMetaFunction *func, int index)
 {
     QString result;
@@ -903,15 +931,6 @@ QString msgCannotFindView(const QString &viewedName, const QString &name)
         + u" for "_s + name;
 }
 
-QString msgCannotFindSnippet(const QString &file, const QString &snippetLabel)
-{
-    QString result;
-    QTextStream str(&result);
-    str << "Cannot find snippet \"" << snippetLabel << "\" in "
-        << QDir::toNativeSeparators(file) << '.';
-    return result;
-}
-
 QString msgSnippetError(const QString &context, const char *what)
 {
     return "Error processing code snippet of "_L1 + context
@@ -1053,3 +1072,45 @@ QString msgCannotFindQDocFile(const AbstractMetaClassCPtr &metaClass,
         << "), tried: " << nativeCandidates.join(", "_L1);
     return result;
 }
+
+QString msgCannotCall(const AbstractMetaFunctionCPtr &func,
+                      int arg, bool injectCodeCallsFunc, bool hasConversionRule)
+{
+    QString result;
+    QTextStream str(&result);
+    str << "No way to generate a binding call for \"" << func->ownerClass()->name() << "::"
+        << func->signature() << '"';
+    if (func->isUserAdded())
+        str << " (user added)";
+    str << " with the modifications for argument " << (arg + 1) << ':';
+    if (!injectCodeCallsFunc)
+        str << " There is no code injection calling the function.";
+    if (!hasConversionRule)
+        str << " There is no conversion rule.";
+    return result;
+}
+
+QString msgRemoveRedundantOverload(const AbstractMetaFunctionCPtr &func,
+                                   const QString &type)
+{
+    return "Removing \""_L1 + func->classQualifiedSignature()
+           + "\" due to presence of an overload taking a \""_L1
+           + type + "\" parameter."_L1;
+}
+
+QString msgCommandLineArguments(const QStringList &argv)
+{
+    QString result = "Host platform: "_L1 + QLatin1StringView(QLibraryInfo::build())
+                     + "\nCommand line:\n   "_L1;
+    for (const QString &arg : argv) {
+        result.append(u' ');
+        const bool quote = arg.contains(u' ');
+        if (quote)
+            result.append(u'"');
+        result.append(arg);
+        if (quote)
+            result.append(u'"');
+    }
+    result.append(u'\n');
+    return result;
+}
