@@ -9,7 +9,7 @@
 #include "modifications_typedefs.h"
 #include "typesystem_typedefs.h"
 
-#include <QtCore/QString>
+#include <QtCore/qstring.h>
 
 class EnumTypeEntry;
 class FunctionTypeEntry;
@@ -37,12 +37,17 @@ QString msgUnnamedArgumentDefaultExpression(const AbstractMetaClassCPtr &context
 
 QString msgArgumentIndexOutOfRange(const AbstractMetaFunction *func, int index);
 
+QString msgModificationCandidates(const AbstractMetaFunctionCPtr &function);
+
 QString msgNoFunctionForModification(const AbstractMetaClassCPtr &klass,
                                      const QString &signature,
                                      const QString &originalSignature,
                                      const QStringList &possibleSignatures,
                                      const AbstractMetaFunctionCList &allFunctions);
 
+QString msgModificationConstMismatch(const AbstractMetaFunctionCPtr &function,
+                                     const QString &modificationSignature);
+
 QString msgTypeModificationFailed(const QString &type, int n,
                                   const AbstractMetaFunction *func,
                                   const QString &why);
@@ -278,4 +283,9 @@ QString msgCannotFindQDocFile(const AbstractMetaClassCPtr &metaClass,
 QString msgCannotCall(const AbstractMetaFunctionCPtr &func,
                       int arg, bool injectCodeCallsFunc, bool hasConversionRule);
 
+QString msgRemoveRedundantOverload(const AbstractMetaFunctionCPtr &func,
+                                   const QString &type);
+
+QString msgCommandLineArguments(const QStringList &argv);
+
 #endif // MESSAGES_H
