@@ -8,9 +8,9 @@
 #include <sourcelocation.h>
 #include <debughelpers_p.h>
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QRegularExpression>
+#include <QtCore/qdebug.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qregularexpression.h>
 
 #include <algorithm>
 
@@ -1100,6 +1100,8 @@ CodeModel::FunctionType _FunctionModelItem::_determineTypeHelper() const
     case CodeModel::Constructor:
     case CodeModel::CopyConstructor:
     case CodeModel::MoveConstructor:
+    case CodeModel::AssignmentOperator:
+    case CodeModel::MoveAssignmentOperator:
     case CodeModel::Destructor:
     case CodeModel::Signal:
     case CodeModel::Slot:
@@ -1113,6 +1115,24 @@ CodeModel::FunctionType _FunctionModelItem::_determineTypeHelper() const
         return m_functionType;
 
     auto newType = newTypeOpt.value();
+    // If clang did not pre-detect AssignmentOperator for some operator=(),
+    // it is an assignment from another type which we are not interested in.
+    if (newType == CodeModel::AssignmentOperator) {
+#ifndef CLANG_HAS_ASSIGNMENT_OPERATOR_CHECK
+        // For clang 14 (Yocto), add a manual check.
+        if (m_arguments.size() == 1 && !type().isVoid()
+            && type().qualifiedName() == m_arguments.constFirst()->type().qualifiedName()) {
+            switch (m_arguments.constFirst()->type().referenceType()) {
+            case NoReference:
+            case LValueReference:
+                return CodeModel::AssignmentOperator;
+            case RValueReference:
+                return CodeModel::MoveAssignmentOperator;
+            }
+        }
+#endif // !CLANG_HAS_ASSIGNMENT_OPERATOR_CHECK
+        return CodeModel::OtherAssignmentOperator;
+    }
     // It's some sort of dereference operator?!
     if (m_arguments.isEmpty()) {
         switch (newType) {
