@@ -3,10 +3,13 @@
 
 #include "reporthandler.h"
 #include "typedatabase.h"
+#include "messages.h"
+
+#include <QtCore/qelapsedtimer.h>
+#include <QtCore/qfile.h>
+#include <QtCore/qoperatingsystemversion.h>
+#include <QtCore/qset.h>
 
-#include <QtCore/QElapsedTimer>
-#include <QtCore/QOperatingSystemVersion>
-#include <QtCore/QSet>
 #include <cstring>
 #include <cstdarg>
 #include <cstdio>
@@ -195,3 +198,25 @@ QByteArray ReportHandler::doneMessage()
         result += " (" + QByteArray::number(m_suppressedCount) + " known issues)";
     return  result;
 }
+
+static QStringList generalMessages;
+
+void ReportHandler::addGeneralMessage(const QString &message)
+{
+    generalMessages.append(message);
+}
+
+void ReportHandler::writeGeneralLogFile(const QString &directory)
+{
+    if (generalMessages.isEmpty())
+        return;
+    QFile file(directory + "/mjb_shiboken.log"_L1);
+    if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
+        qWarning(lcShiboken, "%s", qPrintable(msgCannotOpenForWriting(file)));
+        return;
+    }
+    for (const auto &m : std::as_const(generalMessages)) {
+        file.write(m.toUtf8());
+        file.putChar('\n');
+    }
+}
