@@ -4,7 +4,7 @@
 #ifndef TESTMULTIPLEINHERITANCE_H
 #define TESTMULTIPLEINHERITANCE_H
 
-#include <QtCore/QObject>
+#include <QtCore/qobject.h>
 
 class AbstractMetaBuilder;
 
