@@ -2,11 +2,13 @@
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include "testvaluetypedefaultctortag.h"
-#include <QtTest/QTest>
 #include "testutil.h"
+
 #include <abstractmetalang.h>
 #include <complextypeentry.h>
 
+#include <QtTest/qtest.h>
+
 void TestValueTypeDefaultCtorTag::testValueTypeDefaultCtorTagArgument()
 {
     const char cppCode[] = "\n\
