@@ -31,14 +31,14 @@
 
 #include "qtcompat.h"
 
-#include <QtCore/QBuffer>
-#include <QtCore/QFile>
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QList>
-#include <QtCore/QRegularExpression>
-#include <QtCore/QVersionNumber>
-#include <QtCore/QXmlStreamReader>
+#include <QtCore/qbuffer.h>
+#include <QtCore/qfile.h>
+#include <QtCore/qdebug.h>
+#include <QtCore/qdir.h>
+#include <QtCore/qlist.h>
+#include <QtCore/qregularexpression.h>
+#include <QtCore/qversionnumber.h>
+#include <QtCore/qxmlstream.h>
 #include "reporthandler.h"
 
 #include <algorithm>
@@ -278,6 +278,7 @@ struct TypeDatabasePrivate : public TypeDatabaseOptions
 
     AddedFunctionList m_globalUserFunctions;
     FunctionModificationList m_functionMods;
+    OverloadRemovalRules m_overloadRemovalRules;
 
     QStringList m_requiredTargetImports;
 
@@ -858,7 +859,8 @@ void TypeDatabase::addTemplate(const TemplateEntryPtr &t)
 
 void TypeDatabase::addTemplate(const QString &name, const QString &code)
 {
-    auto te = std::make_shared<TemplateEntry>(name);
+    auto te = std::make_shared<TemplateEntry>();
+    te->setName(name);
     te->addCode(code);
     addTemplate(te);
 }
@@ -905,6 +907,16 @@ FunctionModificationList
     return lst;
 }
 
+const OverloadRemovalRules &TypeDatabase::overloadRemovalRules() const
+{
+    return d->m_overloadRemovalRules;
+}
+
+void TypeDatabase::addOverloadRemovalRule(const OverloadRemovalRule &r)
+{
+    d->m_overloadRemovalRules.append(r);
+}
+
 bool TypeDatabase::addSuppressedWarning(const QString &warning, bool generate,
                                         QString *errorMessage)
 {
@@ -1182,7 +1194,12 @@ bool TypeDatabasePrivate::parseFile(const TypeDatabaseParserContextPtr &context,
                                     QIODevice *device, bool generate)
 {
     ConditionalStreamReader reader(device);
-    reader.setConditions(context->db->typesystemKeywords());
+    const auto typesystemKeywords = context->db->typesystemKeywords();
+    if (generate) {
+        ReportHandler::addGeneralMessage("Type System keywords: "_L1
+                                         + typesystemKeywords.join(", "_L1) + u'\n');
+    }
+    reader.setConditions(typesystemKeywords);
     TypeSystemParser handler(context, generate);
     const bool result = handler.parse(reader);
     if (!result) {
