@@ -4,7 +4,7 @@
 #include "generatorcontext.h"
 #include <abstractmetalang.h>
 
-#include <QtCore/QDebug>
+#include <QtCore/qdebug.h>
 
 using namespace Qt::StringLiterals;
 
