@@ -8,9 +8,9 @@
 #include "include.h"
 #include "modifications_typedefs.h"
 
-#include <QtCore/QFlags>
-#include <QtCore/QSet>
-#include <QtCore/QHash>
+#include <QtCore/qflags.h>
+#include <QtCore/qset.h>
+#include <QtCore/qhash.h>
 
 #include <memory>
 #include <utility>
@@ -146,6 +146,8 @@ private:
     void writeConstructorWrapper(TextStream &s,
                                  const OverloadData &overloadData,
                                  const GeneratorContext &classContext) const;
+    static void writeConstructorDummy(TextStream &s, const GeneratorContext &classContext,
+                                      const char *errorMessageFunc);
     void writeMethodWrapper(TextStream &s, const OverloadData &overloadData,
                             const GeneratorContext &classContext) const;
     void writeMethodWrapper(TextStream &s, TextStream &definitionStream,
