@@ -32,13 +32,15 @@
 #include <algorithm>
 #include <set>
 
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
-#include <QtCore/QVariant>
-#include <QtCore/QDebug>
+#include <QtCore/qdir.h>
+#include <QtCore/qtextstream.h>
+#include <QtCore/qvariant.h>
+#include <QtCore/qdebug.h>
 
 using namespace Qt::StringLiterals;
 
+using FunctionSet = QSet<AbstractMetaFunctionCPtr>;
+
 struct IndexValue
 {
     QString name; // "SBK_..."
@@ -46,6 +48,22 @@ struct IndexValue
     QString comment;
 };
 
+// Returns the methods hidden from base classes
+static FunctionSet getHiddenOverloads(const AbstractMetaFunctionCPtr &func)
+{
+    FunctionSet result;
+    // Check if this method hide other methods in base classes
+    auto hiddenBy = [&func](const AbstractMetaFunctionCPtr &f) {
+        return f != func && !f->isConstructor() && !f->isPrivate() && !f->isVirtual()
+               && !f->isUserAdded() && !f->isAbstract() && !f->isStatic()
+               && f->name() == func->name();
+    };
+    const auto &functions = func->ownerClass()->functions();
+    std::copy_if(functions.cbegin(), functions.cend(),
+                 std::inserter(result, result.end()), hiddenBy);
+    return result;
+}
+
 TextStream &operator<<(TextStream &s, const IndexValue &iv)
 {
     s << "    " << AlignedField(iv.name, 56) << " = " << iv.value << ',';
@@ -97,10 +115,10 @@ void HeaderGenerator::writeCopyCtor(TextStream &s,
                                     const AbstractMetaClassCPtr &metaClass)
 {
     s << wrapperName(metaClass) << "(const " << metaClass->qualifiedCppName()
-      << "& self) : " << metaClass->qualifiedCppName() << "(self)\n{\n}\n\n";
+      << "& self) : " << metaClass->qualifiedCppName() << "(self)\n{\n}\n";
 }
 
-static void writeProtectedEnums(TextStream &s, const AbstractMetaClassCPtr &metaClass)
+static void writeProtectedEnumsHelper(TextStream &s, const AbstractMetaClassCPtr &metaClass)
 {
     const QString name = metaClass->qualifiedCppName();
     for (const auto &e : metaClass->enums()) {
@@ -168,6 +186,8 @@ void HeaderGenerator::writeWrapperClass(TextStream &s,
             s << includeGroup;
     }
 
+    s << "namespace Shiboken { struct AutoDecRef; class GilState; }\n\n";
+
     if (usePySideExtensions() && isQObject(metaClass))
         s << "namespace PySide { class DynamicQMetaObject; }\n\n";
 
@@ -214,57 +234,24 @@ void HeaderGenerator::writeWrapperClassDeclaration(TextStream &s,
 {
     const AbstractMetaClassCPtr &metaClass = classContext.metaClass();
     const auto typeEntry = metaClass->typeEntry();
-    InheritedOverloadSet inheritedOverloads;
 
     // Class
     s << "class " << wrapperName
       << " : public " << metaClass->qualifiedCppName()
-      << "\n{\npublic:\n" << indent
-      << wrapperName << "(const " << wrapperName << " &) = delete;\n"
-      << wrapperName << "& operator=(const " << wrapperName << " &) = delete;\n"
-      << wrapperName << '(' << wrapperName << " &&) = delete;\n"
-      << wrapperName << "& operator=(" << wrapperName << " &&) = delete;\n\n";
+      << "\n{\npublic:\n" << indent;
 
-    // Make protected enums accessible
-    if (avoidProtectedHack()) {
-        recurseClassHierarchy(metaClass, [&s] (const AbstractMetaClassCPtr &metaClass) {
-            writeProtectedEnums(s, metaClass);
-            return false;
-        });
-    }
-
-    if (avoidProtectedHack() && metaClass->hasProtectedFields()) {
-        s << "\n// Make protected fields accessible\n";
-        const QString name = metaClass->qualifiedCppName();
-        for (const auto &f : metaClass->fields()) {
-            if (f.isProtected())
-                s << "using " << name << "::"  << f.originalName() << ";\n";
-        }
-        s << '\n';
-    }
+    writeProtectedEnums(s, classContext);
+    writeSpecialFunctions(s, wrapperName, classContext);
 
     int maxOverrides = 0;
     for (const auto &func : metaClass->functions()) {
         const auto generation = functionGeneration(func);
-        writeFunction(s, func, &inheritedOverloads, generation);
+        writeFunction(s, func, generation);
         // PYSIDE-803: Build a boolean cache for unused overrides.
         if (generation.testFlag(FunctionGenerationFlag::VirtualMethod))
             maxOverrides++;
     }
 
-    //destructor
-    // PYSIDE-504: When C++ 11 is used, then the destructor must always be declared.
-    if (!avoidProtectedHack() || !metaClass->hasPrivateDestructor()
-        || alwaysGenerateDestructorDeclaration()) {
-        if (avoidProtectedHack() && metaClass->hasPrivateDestructor())
-            s << "// C++11: need to declare (unimplemented) destructor because "
-                 "the base class destructor is private.\n";
-        s << '~' << wrapperName << "()";
-        if (metaClass->hasVirtualDestructor())
-            s << " override";
-        s << ";\n";
-    }
-
     writeClassCodeSnips(s, typeEntry->codeSnips(),
                         TypeSystem::CodeSnipPositionDeclaration, TypeSystem::NativeCode,
                         classContext);
@@ -277,12 +264,6 @@ void *qt_metacast(const char *_clname) override;
 )";
     }
 
-    if (!inheritedOverloads.isEmpty()) {
-        s << "// Inherited overloads, because the using keyword sux\n";
-        for (const auto &func : std::as_const(inheritedOverloads))
-            writeMemberFunctionWrapper(s, func);
-    }
-
     if (usePySideExtensions())
         s << "static void pysideInitQtMetaTypes();\n";
 
@@ -290,9 +271,11 @@ void *qt_metacast(const char *_clname) override;
     Q_ASSERT(maxOverrides > 0 || !needsMethodCache);
 
     if (needsMethodCache)
-        s << "void resetPyMethodCache();\n";
+        s << "\nvoid resetPyMethodCache();\n";
 
-    s << outdent << "private:\n" << indent;
+    writeProtectedFields(s, classContext);
+
+    s << outdent << "\nprivate:\n" << indent;
 
     if (!metaClass->userAddedPythonOverrides().isEmpty()) {
         for (const auto &f : metaClass->userAddedPythonOverrides())
@@ -310,6 +293,70 @@ void *qt_metacast(const char *_clname) override;
     s << outdent << "};\n\n";
 }
 
+void HeaderGenerator::writeSpecialFunctions(TextStream &s, const QString &wrapperName,
+                                            const GeneratorContext &classContext) const
+{
+    const AbstractMetaClassCPtr &metaClass = classContext.metaClass();
+
+    const auto &wrapperConstructors = ShibokenGenerator::getWrapperConstructors(metaClass);
+    for (const auto &func : wrapperConstructors)
+        writeConstructor(s, func);
+    s << wrapperName << "(const " << wrapperName << " &) = delete;\n";
+    // Special inline copy CT (Wrapper from metaClass)
+    const auto &copyConstructors = metaClass->queryFunctions(FunctionQueryOption::CopyConstructor);
+    if (!copyConstructors.isEmpty()) {
+        auto generation = functionGeneration(copyConstructors.constFirst());
+        if (generation.testFlag(FunctionGenerationFlag::WrapperSpecialCopyConstructor))
+            writeCopyCtor(s, metaClass);
+    }
+    s << wrapperName << "& operator=(const " << wrapperName << " &) = delete;\n"
+      << wrapperName << '(' << wrapperName << " &&) = delete;\n"
+      << wrapperName << "& operator=(" << wrapperName << " &&) = delete;\n";
+
+    // destructor
+    // PYSIDE-504: When C++ 11 is used, then the destructor must always be declared.
+    if (!avoidProtectedHack() || !metaClass->hasPrivateDestructor()
+        || alwaysGenerateDestructorDeclaration()) {
+        if (avoidProtectedHack() && metaClass->hasPrivateDestructor())
+            s << "// C++11: need to declare (unimplemented) destructor because "
+                 "the base class destructor is private.\n";
+        s << '~' << wrapperName << "()";
+        if (metaClass->hasVirtualDestructor())
+            s << " override";
+        s << ";\n\n";
+    }
+}
+
+void HeaderGenerator::writeProtectedEnums(TextStream &s,
+                                          const GeneratorContext &classContext)
+{
+    // Make protected enums accessible
+    if (avoidProtectedHack()) {
+        const auto lastPos = s.pos();
+        const AbstractMetaClassCPtr &metaClass = classContext.metaClass();
+        recurseClassHierarchy(metaClass, [&s] (const AbstractMetaClassCPtr &metaClass) {
+            writeProtectedEnumsHelper(s, metaClass);
+            return false;
+        });
+        if (s.pos() != lastPos)
+            s << '\n';
+    }
+}
+
+void HeaderGenerator::writeProtectedFields(TextStream &s,
+                                           const GeneratorContext &classContext)
+{
+    const AbstractMetaClassCPtr &metaClass = classContext.metaClass();
+    if (avoidProtectedHack() && metaClass->hasProtectedFields()) {
+        s << "\n// Make protected fields accessible\n";
+        const QString name = metaClass->qualifiedCppName();
+        for (const auto &f : metaClass->fields()) {
+            if (f.isProtected())
+                s << "using " << name << "::"  << f.originalName() << ";\n";
+        }
+    }
+}
+
 // Write an inline wrapper around a function
 void HeaderGenerator::writeMemberFunctionWrapper(TextStream &s,
                                                  const AbstractMetaFunctionCPtr &func,
@@ -343,7 +390,7 @@ void HeaderGenerator::writeMemberFunctionWrapper(TextStream &s,
             enumTypeEntry = type.typeEntry();
         if (enumTypeEntry) {
             s << type.cppSignature() << '(' << arg.name() << ')';
-        } else if (type.passByValue() && type.isUniquePointer()) {
+        } else if (type.useStdMove()) {
             s << stdMove(arg.name());
         } else {
             s << arg.name();
@@ -352,51 +399,41 @@ void HeaderGenerator::writeMemberFunctionWrapper(TextStream &s,
     s << "); }\n";
 }
 
+void HeaderGenerator::writeConstructor(TextStream &s, const AbstractMetaFunctionCPtr &func) const
+{
+    Options option = func->hasSignatureModifications()
+    ? Generator::OriginalTypeDescription : Generator::NoOption;
+    s << functionSignature(func, {}, {}, option) << ";\n";
+}
+
 void HeaderGenerator::writeFunction(TextStream &s, const AbstractMetaFunctionCPtr &func,
-                                    InheritedOverloadSet *inheritedOverloads,
                                     FunctionGeneration generation) const
 {
-
-    // do not write copy ctors here.
-    if (generation.testFlag(FunctionGenerationFlag::WrapperSpecialCopyConstructor)) {
-        writeCopyCtor(s, func->ownerClass());
-        return;
-    }
-
     if (generation.testFlag(FunctionGenerationFlag::ProtectedWrapper))
         writeMemberFunctionWrapper(s, func, u"_protected"_s);
 
-    if (generation.testFlag(FunctionGenerationFlag::WrapperConstructor)) {
-        Options option =  func->hasSignatureModifications()
-            ? Generator::OriginalTypeDescription : Generator::NoOption;
-        s << functionSignature(func, {}, {}, option) << ";\n";
+    if (!generation.testFlag(FunctionGenerationFlag::VirtualMethod))
         return;
+
+    const Options options = Generator::OriginalTypeDescription;
+    s << functionSignature(func, {}, {}, options)
+        << " override;\n";
+
+    if (!getReusedOverridenFunctions(func->ownerClass()).contains(func)) {
+        s << functionSignature(func, {}, {}, options | Generator::PythonOverrideImplementation)
+            << ";\n";
     }
 
-    const bool isVirtual = generation.testFlag(FunctionGenerationFlag::VirtualMethod);
-    if (isVirtual) {
-        s << functionSignature(func, {}, {}, Generator::OriginalTypeDescription)
-            << " override;\n";
+    const auto &hiddenOverloads = getHiddenOverloads(func);
+    if (!hiddenOverloads.isEmpty()) {
+        s << "// Inherited overloads, because the using keyword sux\n";
+        for (const auto &func : hiddenOverloads)
+            writeMemberFunctionWrapper(s, func);
+        s << '\n';
     }
 
-    // Check if this method hide other methods in base classes
-    if (isVirtual) {
-        for (const auto &f : func->ownerClass()->functions()) {
-            if (f != func
-                && !f->isConstructor()
-                && !f->isPrivate()
-                && !f->isVirtual()
-                && !f->isAbstract()
-                && !f->isStatic()
-                && f->name() == func->name()) {
-                inheritedOverloads->insert(f);
-            }
-        }
-
-        // TODO: when modified an abstract method ceases to be virtual but stays abstract
-        //if (func->isModifiedRemoved() && func->isAbstract()) {
-        //}
-    }
+    // TODO: when modified an abstract method ceases to be virtual but stays abstract
+    //if (func->isModifiedRemoved() && func->isAbstract()) {
 }
 
 // Find equivalent typedefs "using Foo=QList<int>", "using Bar=QList<int>"
