@@ -11,7 +11,8 @@
 #include "typesystem_typedefs.h"
 #include "typesystem_enums.h"
 
-#include <QtCore/QRegularExpression>
+#include <QtCore/qhash.h>
+#include <QtCore/qregularexpression.h>
 
 #include <array>
 #include <optional>
@@ -82,6 +83,7 @@ public:
     };
     Q_DECLARE_FLAGS(AttroCheck, AttroCheckFlag);
 
+    using FunctionMapping = QHash<AbstractMetaFunctionCPtr, AbstractMetaFunctionCPtr>;
     using FunctionGroups = QMap<QString, AbstractMetaFunctionCList>; // Sorted
 
     ShibokenGenerator();
@@ -109,6 +111,15 @@ protected:
      */
     FunctionGroups getGlobalFunctionGroups() const;
     static FunctionGroups getFunctionGroups(const AbstractMetaClassCPtr &scope);
+    /// Returns the constructors for which bindings should be generated.
+    /// \param scope Where to search for functions
+    static AbstractMetaFunctionCList getConstructors(const AbstractMetaClassCPtr &scope);
+    /// Returns the constructors which should be added to wrapper class.
+    /// \param scope Where to search for functions
+    static AbstractMetaFunctionCList getWrapperConstructors(const AbstractMetaClassCPtr &scope);
+    /// Returns mapping of virtual functions whose override handling code can be re-used.
+    static const FunctionMapping &
+        getReusedOverridenFunctions(const AbstractMetaClassCPtr &scope);
 
     static QList<AbstractMetaFunctionCList>
         numberProtocolOperators(const AbstractMetaClassCPtr &scope);
@@ -215,10 +226,12 @@ protected:
 
     static QString fullPythonClassName(const AbstractMetaClassCPtr &metaClass);
 
+    static QString headerFileNameForClass(const AbstractMetaClassCPtr &metaClass);
     static QString headerFileNameForContext(const GeneratorContext &context);
     IncludeGroup baseWrapperIncludes(const GeneratorContext &classContext) const;
 
     static QString fullPythonFunctionName(const AbstractMetaFunctionCPtr &func, bool forceFunc);
+    static QString pythonOverrideImplName(const AbstractMetaFunctionCPtr &func);
 
     static bool wrapperDiagnostics();
 
@@ -370,13 +383,17 @@ private:
 
     static const GeneratorClassInfoCacheEntry &
         getGeneratorClassInfo(const AbstractMetaClassCPtr &scope);
-    static FunctionGroups getFunctionGroupsImpl(const AbstractMetaClassCPtr &scope);
+    static FunctionGroups getFunctionGroupsImpl(const AbstractMetaClassCPtr &scope,
+                                                AbstractMetaFunctionCList *constructors);
+    static AbstractMetaFunctionCList wrapperConstructorsImpl(const AbstractMetaClassCPtr &scope);
+    static AbstractMetaFunctionCList getWrapperConstructorsFromUsingDirective(const AbstractMetaClassCPtr &scope);
     static QList<AbstractMetaFunctionCList>
         getNumberProtocolOperators(const AbstractMetaClassCPtr &metaClass);
     static BoolCastFunctionOptional getBoolCast(const AbstractMetaClassCPtr &metaClass);
     static bool classNeedsGetattroOverloadFunctionImpl(const FunctionGroups &functionGroups);
     static AttroCheck checkAttroFunctionNeedsImpl(const AbstractMetaClassCPtr &metaClass,
                                                   const FunctionGroups &functionGroups);
+    static FunctionMapping getReusedOverridesImpl(const AbstractMetaClassCPtr &metaClass);
     static bool isVirtualOverride(const AbstractMetaFunctionCPtr &f);
 
     QString translateTypeForWrapperMethod(const AbstractMetaType &cType,
