@@ -1065,6 +1065,16 @@ introduceWrapperType(PyObject *enclosingObject,
     setDestructorFunction(type, cppObjDtor);
     auto *ob_type = reinterpret_cast<PyObject *>(type);
 
+    if (wrapperFlags & InternalWrapper) {
+        // Type wraps another wrapper class and isn't part of any module.  This is used to extend
+        // Qt types with additional functionality, but from within PySide itself.  In order for
+        // the re-wrapped class to call the autogenerated __init__ method, is_user_type must be set
+        // to 1.  Otherwise the Shiboken::ObjectType::canCallConstructor test will fail.
+        // This is currently only used by QtRemoteObjects to create types dynamically.
+        sotp->is_user_type = 1;
+        return type;
+    }
+
     if (wrapperFlags & InnerClass) {
         // PYSIDE-2230: Instead of tp_dict, use the enclosing type.
         //              This stays interface compatible.
@@ -1435,7 +1445,7 @@ bool isValid(PyObject *pyObj)
         return true;
     }
 
-    auto priv = reinterpret_cast<SbkObject *>(pyObj)->d;
+    auto *priv = reinterpret_cast<SbkObject *>(pyObj)->d;
 
     if (!priv->cppObjectCreated && isUserType(pyObj)) {
         PyErr_Format(PyExc_RuntimeError, "'__init__' method of object's base class (%s) not called.",
