@@ -265,47 +265,6 @@ enum PepUnicode_Kind {
 #define _PepUnicode_IS_ASCII     PyUnicode_IS_ASCII
 #endif
 
-/*****************************************************************************
- *
- * RESOLVED: bytesobject.h
- *
- */
-#ifdef Py_LIMITED_API
-#define PyBytes_AS_STRING(op)       PyBytes_AsString(op)
-#define PyBytes_GET_SIZE(op)        PyBytes_Size(op)
-#endif
-
-/*****************************************************************************
- *
- * RESOLVED: floatobject.h
- *
- */
-#ifdef Py_LIMITED_API
-#define PyFloat_AS_DOUBLE(op)       PyFloat_AsDouble(op)
-#endif
-
-/*****************************************************************************
- *
- * RESOLVED: tupleobject.h
- *
- */
-#ifdef Py_LIMITED_API
-#define PyTuple_GET_ITEM(op, i)     PyTuple_GetItem((PyObject *)op, i)
-#define PyTuple_SET_ITEM(op, i, v)  PyTuple_SetItem(op, i, v)
-#define PyTuple_GET_SIZE(op)        PyTuple_Size((PyObject *)op)
-#endif
-
-/*****************************************************************************
- *
- * RESOLVED: listobject.h
- *
- */
-#ifdef Py_LIMITED_API
-#define PyList_GET_ITEM(op, i)      PyList_GetItem(op, i)
-#define PyList_SET_ITEM(op, i, v)   PyList_SetItem(op, i, v)
-#define PyList_GET_SIZE(op)         PyList_Size(op)
-#endif
-
 /*****************************************************************************
  *
  * RESOLVED: methodobject.h
@@ -315,13 +274,11 @@ enum PepUnicode_Kind {
 #ifdef Py_LIMITED_API
 
 using PyCFunctionObject = struct _pycfunc;
-#define PyCFunction_GET_FUNCTION(func)  PyCFunction_GetFunction((PyObject *)func)
-#define PyCFunction_GET_SELF(func)      PyCFunction_GetSelf((PyObject *)func)
-#define PyCFunction_GET_FLAGS(func)     PyCFunction_GetFlags((PyObject *)func)
 #define PepCFunction_GET_NAMESTR(func) \
     _PepUnicode_AsString(PyObject_GetAttrString((PyObject *)func, "__name__"))
 #else
-#define PepCFunction_GET_NAMESTR(func)        ((func)->m_ml->ml_name)
+#define PepCFunction_GET_NAMESTR(func) \
+    (reinterpret_cast<const PyCFunctionObject *>(func)->m_ml->ml_name)
 #endif
 
 /*****************************************************************************
