@@ -17,7 +17,7 @@ This module configures the different layouts which can be used.
 It also implements them in this file. The configurations are
 used literally as strings like "signature", "existence", etc.
 """
-
+# flake8: noqa E:731
 import inspect
 import operator
 import sys
@@ -27,9 +27,10 @@ import typing
 from functools import reduce
 from types import SimpleNamespace
 from textwrap import dedent
-from shibokensupport.signature.mapping import ellipsis, missing_optional_return
+from shibokensupport.signature.mapping import ellipsis, missing_optional_return, PlaceholderType
 from shibokensupport.signature.parser import using_snake_case
 from shibokensupport.signature import make_snake_case_name
+from collections.abc import Sequence, Iterable
 
 DEFAULT_PARAM_KIND = inspect.Parameter.POSITIONAL_ONLY
 
@@ -134,9 +135,14 @@ _KEYWORD_ONLY            = inspect.Parameter.KEYWORD_ONLY           # noqa E:201
 _VAR_KEYWORD             = inspect.Parameter.VAR_KEYWORD            # noqa E:201
 _empty                   = inspect.Parameter.empty                  # noqa E:201
 
-
+# PYSIDE-3098: Iterable and Sequence can occur together in an overload.
+#              This needs sorting in order of generality.
+# This happened in the NumPy support of PySide 6.10. Note that the ordering
+# of methods there is completely different and unrelated to this mypy sorting.
 default_weights = {
     typing.Any: 1000,   # noqa E:241
+    Iterable:    500,   # noqa E:241
+    Sequence:    400,   # noqa E:241
     bool:        101,   # noqa E:241
     int:         102,   # noqa E:241
     float:       103,   # noqa E:241
@@ -144,6 +150,10 @@ default_weights = {
 }
 
 
+_ignore_mro = type, None, typing.Any, typing.TypeVar, typing.Type[PlaceholderType]
+mro_len = lambda ann: len(ann.mro()) if ann not in _ignore_mro and hasattr(ann, "mro") else 0
+
+
 def get_ordering_key(anno):
     """
     This is the main sorting algorithm for annotations.
@@ -185,12 +195,12 @@ def get_ordering_key(anno):
             # Normal: Use the union arg with the shortest mro().
             leng = 9999
             for ann in typing_args:
-                lng = len(ann.mro())
+                lng = mro_len(ann)
                 if lng < leng:
                     leng = lng
                     anno = ann
     else:
-        leng = len(anno.mro()) if anno not in (type, None, typing.Any) else 0
+        leng = mro_len(anno)
         parts = 1
     if anno in default_weights:
         leng = - default_weights[anno]
@@ -342,6 +352,7 @@ def create_signature_union(props, key):
                 if last == _VAR_POSITIONAL:
                     kind = _KEYWORD_ONLY
         if default is None:
+            ann = typing.Union[ann]
             ann = typing.Optional[ann]
         if default is not _empty and layout.ellipsis:
             default = ellipsis
@@ -363,6 +374,7 @@ def create_signature_union(props, key):
 
     ret_anno = annotations.get('return', _empty)
     if ret_anno is not _empty and props["fullname"] in missing_optional_return:
+        ret_anno = typing.Union[ret_anno]
         ret_anno = typing.Optional[ret_anno]
     return inspect.Signature(params, return_annotation=ret_anno,
                              __validate_parameters__=False)
@@ -370,7 +382,7 @@ def create_signature_union(props, key):
 
 def transform(signature):
     # Change the annotations of the parameters to use "|" syntax.
-    parameters = []
+    params = []
     changed = False
     for idx, param in enumerate(signature.parameters.values()):
         ann = param.annotation
@@ -379,9 +391,13 @@ def transform(signature):
             ann = reduce(operator.or_, args)
             param = param.replace(annotation=ann)
             changed = True
-        parameters.append(param)
-
-    return signature.replace(parameters=parameters) if changed else signature
+        params.append(param)
+    ann = signature.return_annotation
+    if typing.get_origin(ann) is typing.Union:
+        args = typing.get_args(ann)
+        ann = reduce(operator.or_, args)
+        changed = True
+    return signature.replace(parameters=params, return_annotation=ann) if changed else signature
 
 
 def create_signature(props, key):
