@@ -10,6 +10,8 @@ import re
 import sys
 import typing
 import warnings
+import collections.abc
+import abc
 
 from types import SimpleNamespace
 from shibokensupport.signature.mapping import (type_map, type_map_tuple, update_mapping,
@@ -74,6 +76,9 @@ def _get_flag_enum_option():
     # _PepUnicode_AsString: Fix a broken promise
     if pyminver and pyminver >= (3, 10):
         warnings.warn(f"{p} _PepUnicode_AsString can now be replaced by PyUnicode_AsUTF8! ***")
+    # PYSIDE-3012: Emit a warning when we may simplify layout.py and pyi_generator.py
+    if pyminver and pyminver >= (3, 10):
+        warnings.warn(f"{p} layout.py and pyi_generator.py can now remove old code! ***")
     # PYSIDE-1960: Emit a warning when we may remove bufferprocs_py37.(cpp|h)
     if pyminver and pyminver >= (3, 11):
         warnings.warn(f"{p} The files bufferprocs_py37.(cpp|h) should be removed ASAP! ***")
@@ -107,21 +112,21 @@ def dprint(*args, **kw):
             sys.stdout.flush()
 
 
-_cache = {}
+class ArglistParser:
+    def __init__(self):
+        regex = build_brace_pattern(level=3, separators=",")
+        rec = re.compile(regex, flags=re.VERBOSE)
+        self._finditer = rec.finditer
+
+    def parse(self, argstr):
+        return list(x.group(1).strip() for x in self._finditer(argstr))
+
+
+arglistParser = ArglistParser()
 
 
 def _parse_arglist(argstr):
-    # The following is a split re. The string is broken into pieces which are
-    # between the recognized strings. Because the re has groups, both the
-    # strings and the separators are returned, where the strings are not
-    # interesting at all: They are just the commata.
-    key = "_parse_arglist"
-    if key not in _cache:
-        regex = build_brace_pattern(level=3, separators=",")
-        _cache[key] = re.compile(regex, flags=re.VERBOSE)
-    split = _cache[key].split
-    # Note: this list is interspersed with "," and surrounded by ""
-    return [x.strip() for x in split(argstr) if x.strip() not in ("", ",")]
+    return arglistParser.parse(argstr)
 
 
 def _parse_line(line):
@@ -243,7 +248,7 @@ def get_name(thing):
 
 def _resolve_value(thing, valtype, line):
     if thing in ("0", "None") and valtype:
-        if valtype.startswith("PySide6.") or valtype.startswith("typing."):
+        if valtype.startswith(("PySide6.", "typing.", "collections.abc.")):
             return None
         mapped = type_map.get(valtype)
         # typing.Any: '_SpecialForm' object has no attribute '__name__'
@@ -297,13 +302,17 @@ def to_string(thing):
     # so we fall back to use __name__ before the next condition.
     if isinstance(thing, typing.TypeVar):
         return get_name(thing)
-    if hasattr(thing, "__name__") and thing.__module__ != "typing":
+    if hasattr(thing, "__name__") and thing.__module__ not in ("typing", "collections.abc"):
         m = thing.__module__
         dot = "." in str(thing) or m not in (thing.__qualname__, "builtins")
         name = get_name(thing)
         ret = m + "." + name if dot else name
         assert (eval(ret, globals(), namespace))
         return ret
+    elif type(thing) in (abc.ABCMeta, type):
+        # collections.abc.Sequence without argument is very different from typing.
+        # PYSIDE-3147 - type(typing.Union) is a type, not typing._SpecialForm.
+        return f"{thing.__module__}.{thing.__name__}"
     # Note: This captures things from the typing module:
     return str(thing)
 
@@ -328,7 +337,7 @@ def get_from_another_module(thing):
                 type_map[thing] = res
                 return res
             except AttributeError:
-                # Maybe it was anothr module...
+                # Maybe it was another module...
                 pass
     return None
 
@@ -411,7 +420,7 @@ def handle_argvar(obj):
     Currently, the best approximation is types.Sequence.
     We want to change that to types.Iterable in the near future.
     """
-    return _handle_generic(obj, typing.Sequence)
+    return _handle_generic(obj, collections.abc.Sequence)
 
 
 def handle_retvar(obj):
@@ -441,7 +450,11 @@ def calculate_props(line):
             ann = 'nullptr'     # maps to None
             tup = name, ann
             arglist[idx] = tup
-        annotations[name] = _resolve_type(ann, line, 0, handle_argvar, parsed.funcname)
+        # When the variable name from constructor and the property is the same,
+        # one overwrites the other. This is fixed here and the latter is omitted.
+        # The property variables added in layout.py
+        if name not in annotations:
+            annotations[name] = _resolve_type(ann, line, 0, handle_argvar, parsed.funcname)
         if len(tup) == 3:
             default = _resolve_value(tup[2], ann, line)
             # PYSIDE-2846: When creating signatures, the defaults should be hashable.
@@ -491,7 +504,7 @@ def fix_variables(props, line):
     for idx, name in enumerate(varnames):
         ann = safe_annos[name]
         if isinstance(ann, ArrayLikeVariable):
-            ann = typing.Sequence[ann.type]
+            ann = collections.abc.Sequence[ann.type]
             annos[name] = ann
         if not isinstance(ann, ResultVariable):
             continue
